export const ApplicationType = {
  DotBot: 0,
  SailBot: 1,
};

export const ControlModeType = {
  Manual: 0,
  Auto: 1,
};

export const maxWaypoints = 8;

export const lh2_distance_threshold = 0.01;
export const lh2_waypoint_area_radius = 0.07;
export const gps_distance_threshold = 10;  // 10 meters
export const gps_waypoint_area_radius = 15; // 15 meters
